#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 natural-transformation
version:              0.4.1
visibility:           public
id:                   natural-transformation-0.4.1-HFhUgLcP4izBGg69WFUpGo
key:                  natural-transformation-0.4.1-HFhUgLcP4izBGg69WFUpGo
license:              BSD-3-Clause
copyright:            Copyright (c) 2015-2016 The University of Kansas
maintainer:           Andy Gill <andygill@ku.edu>
author:               Andy Gill
stability:            Provisional
homepage:             https://github.com/ku-fpg/natural-transformation
synopsis:             A natural transformation package.
description:
    A natural transformation transforms a container @f a@ into another
    container @g a@. Natural transformations act as functor morphisms
    in category theory.

    The naming of '\''~>'\'', '\'':~>'\'' and '\''$$'\'' were taken,
    with permission, from Edward Kmett'\''s @indexed@ package.

category:             Control
abi:                  d1e09bbce32ed31bf58298780aa4aa3b
exposed:              True
exposed-modules:      Control.Natural Control.Natural.RULES Control.Object
import-dirs:          /usr/lib/ghc-9.6.6/site-local/natural-transformation-0.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/natural-transformation-0.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/natural-transformation-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-natural-transformation
hs-libraries:         HSnatural-transformation-0.4.1-HFhUgLcP4izBGg69WFUpGo
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-natural-transformation/html/natural-transformation.haddock

haddock-html:         /usr/share/doc/haskell-natural-transformation/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

